==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/dnsconf/dnsconf.m <==
extern const char **_dictionary_dnsconf;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_dnsconf;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_dnsconf("dnsconf",_dictionary_dnsconf,184,16);\
	void dummy_dict_dnsconf(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_dnsconf[id]
	#define MSG_B(id,m,n)	_dictionary_dnsconf[id]
	#define MSG_R(id)	_dictionary_dnsconf[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_dnsconf,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_dnsconf,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_dnsconf,id)
#endif
#define F_IPADR	0
#define T_FORWARDERS	1
#define I_FORWARDERS	2
#define M_DOMAINS	3
#define M_IPREV	4
#define M_SECOND	5
#define M_FORWARD	6
#define M_HOSTINFO	7
#define M_CONFIG	8
#define ADDEDIT	9
#define T_DNSCONF	10
#define I_DNSCONF	11
#define Q_NODNS	12
#define I_NODNS	13
#define N_DNSUSAGE	14
#define E_NODNS	15
#define E_NODOMAINS	16
#define F_HOST_DOM	17
#define F_NICKNAME	18
#define F_IPADRS	19
#define F_DNSADV	20
#define F_EMAILADV	21
#define T_HOSTINFO	22
#define I_HOSTINFO	23
#define Q_CONFIRM	24
#define I_CONFIRM	25
#define Q_HOSTNAME	26
#define I_HOSTNAME	27
#define F_NETNUM	28
#define F_DOMAIN	29
#define F_SECREQ	30
#define F_EVERYHOSTS	31
#define T_PRIMSPEC	32
#define I_PRIMSPEC	33
#define E_NODOMAIN	34
#define T_PRIMARYS	35
#define I_PRIMARYS	36
#define I_ADDPRIM	37
#define F_IPSERV	38
#define T_SECSPEC	39
#define I_SECSPEC	40
#define E_FILLDOM	41
#define T_SECONDARYS	42
#define I_SECONDARYS	43
#define I_ADDSEC	44
#define M_IPRANGE	45
#define T_IPRANGE	46
#define I_IPRANGE	47
#define F_IPRANGE	48
#define F_RANGECOMMENT	49
#define F_RANGEFULL	50
#define E_IVLDIPMAP	51
#define Q_DELPRIMARY	52
#define Q_DELSECONDARY	53
#define M_EDITBYDOM	54
#define T_SELHOST	55
#define T_EDITBYDOM	56
#define E_MUSTINSERT	57
#define I_ANEWHOST	58
#define E_NODOMAINDEF	59
#define T_MISSCACHE	60
#define E_MISSCACHE	61
#define I_MISSCACHE	62
#define E_CANTCOPY	63
#define N_DNSCREATED	64
#define Q_RENAME	65
#define T_RENAME	66
#define F_HOST	67
#define T_IPREVERSE	68
#define I_IPREVERSE	69
#define E_NOMATCH	70
#define E_LEXDNS	71
#define N_CONFIG	72
#define E_NOIPWCNAME	73
#define H_SECONDARIES	74
#define H_DOMAIN	75
#define T_DEFAULTIP	76
#define T_IPCONFLICT	77
#define I_IPCONFLICT	78
#define I_DOREV	79
#define F_ALLOCTO	80
#define H_HOST	81
#define E_EXMISSING	82
#define E_DOMEXIST	83
#define E_NORANGE	84
#define E_NOIPAVAIL	85
#define E_IVLDOPT	86
#define M_FEATURES	87
#define F_FORWARDONLY	88
#define I_FORWARDONLY	89
#define F_NORECURSE	90
#define I_NORECURSE	91
#define F_NOFETCHGLUE	92
#define I_NOFETCHGLUE	93
#define F_QUERYLOG	94
#define T_DNSFEATURES	95
#define F_XFERNETS	96
#define F_BOGUSNS	97
#define F_FAKEIQUERY	98
#define N_NOFORWARDER	99
#define M_DNSSERVER	100
#define E_ISASECOND	101
#define E_ISAPRIMARY	102
#define M_dnsconf	103
#define E_IVLDKEYW	104
#define N_DNSUPDATED	105
#define F_SEARCHLIST	106
#define T_FEATURES	107
#define T_MVIRTUAL	108
#define E_VHOSTEXIST	109
#define T_BASEINFO	110
#define E_BIND8LEX	111
#define E_EXPECTARG1	112
#define E_EXPECTTYPE	113
#define E_IVLDIP	114
#define E_ZONETYPE	115
#define E_EXPECTED	116
#define E_IVLDHOSTIP	117
#define E_SETHOSTPART	118
#define F_ALLOWTRANS	119
#define F_ALLOWQUERY	120
#define F_LISTENON	121
#define T_ACCESS	122
#define F_ALLOWUPDATE	123
#define F_ALSONOTIFY	124
#define H_ACLS	125
#define I_ADDMATCH	126
#define T_ACL	127
#define I_ADDACL	128
#define T_ACLS	129
#define M_ACL	130
#define M_LOGGING	131
#define H_ACL	132
#define I_DELACL	133
#define M_SECURITY	134
#define F_NETHOSTACL	135
#define F_NETSIZE	136
#define I_DELADDR	137
#define T_ADDRMATCH	138
#define I_ADDRMATCH	139
#define E_HOSTIP	140
#define E_IVLDACL	141
#define E_NETWORKIP	142
#define E_NETSIZE	143
#define M_ACCESS	144
#define T_DNSACCESS	145
#define B_EDITNAME	146
#define T_ACLNAME	147
#define I_ACLNAME	148
#define E_NOSPACE	149
#define F_ACLNAME	150
#define F_NOTIFY	151
#define I_NO	152
#define I_YES	153
#define I_DEFAULT	154
#define F_SECLIST	155
#define B_PREVIEW	156
#define N_NOTTRANSYET	157
#define F_MAINSERV	158
#define F_ADMINMAIL	159
#define F_REFRESH	160
#define F_RETRY	161
#define F_EXPIRE	162
#define F_TTL	163
#define B_UPDATE	164
#define Q_UPDATESLAVE	165
#define I_UPDATESLAVE	166
#define E_STUBNOTIMPLEMENTED	167
#define M_ZONE_FORWARD	168
#define F_FORLIST	169
#define T_FORSPEC	170
#define I_FORSPEC	171
#define Q_DELFORWARD	172
#define E_FILLDOMU	173
#define H_FORWARDS	174
#define I_ADDFOR	175
#define T_FORWARDS	176
#define I_FORWARDS	177
#define I_BASICCONFLICT	178
#define Q_UPDATEANYWAY	179
#define F_SYNCBASIC	180
#define I_SYNCBASIC	181
#define E_INCLUDE	182
#define E_TOOMANYINCL	183

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/dnsconf/dnsconf.m <==
extern const char **_dictionary_dnsconf;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_dnsconf;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_dnsconf("dnsconf",_dictionary_dnsconf,208,16);\
	void dummy_dict_dnsconf(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_dnsconf[id]
	#define MSG_B(id,m,n)	_dictionary_dnsconf[id]
	#define MSG_R(id)	_dictionary_dnsconf[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_dnsconf,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_dnsconf,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_dnsconf,id)
#endif
#define F_IPADR	0
#define T_FORWARDERS	1
#define I_FORWARDERS	2
#define M_DOMAINS	3
#define M_IPREV	4
#define M_SECOND	5
#define M_FORWARD	6
#define M_HOSTINFO	7
#define M_CONFIG	8
#define ADDEDIT	9
#define T_DNSCONF	10
#define I_DNSCONF	11
#define Q_NODNS	12
#define I_NODNS	13
#define N_DNSUSAGE	14
#define E_NODNS	15
#define E_NODOMAINS	16
#define F_HOST_DOM	17
#define F_NICKNAME	18
#define F_IPADRS	19
#define F_DNSADV	20
#define F_EMAILADV	21
#define T_HOSTINFO	22
#define I_HOSTINFO	23
#define Q_CONFIRM	24
#define I_CONFIRM	25
#define Q_HOSTNAME	26
#define I_HOSTNAME	27
#define F_NETNUM	28
#define F_DOMAIN	29
#define F_SECREQ	30
#define F_EVERYHOSTS	31
#define T_PRIMSPEC	32
#define I_PRIMSPEC	33
#define E_NODOMAIN	34
#define T_PRIMARYS	35
#define I_PRIMARYS	36
#define I_ADDPRIM	37
#define F_IPSERV	38
#define T_SECSPEC	39
#define I_SECSPEC	40
#define E_FILLDOM	41
#define T_SECONDARYS	42
#define I_SECONDARYS	43
#define I_ADDSEC	44
#define M_IPRANGE	45
#define T_IPRANGE	46
#define I_IPRANGE	47
#define F_IPRANGE	48
#define F_RANGECOMMENT	49
#define F_RANGEFULL	50
#define E_IVLDIPMAP	51
#define Q_DELPRIMARY	52
#define Q_DELSECONDARY	53
#define M_EDITBYDOM	54
#define T_SELHOST	55
#define T_EDITBYDOM	56
#define E_MUSTINSERT	57
#define I_ANEWHOST	58
#define E_NODOMAINDEF	59
#define T_MISSCACHE	60
#define E_MISSCACHE	61
#define I_MISSCACHE	62
#define E_CANTCOPY	63
#define N_DNSCREATED	64
#define Q_RENAME	65
#define T_RENAME	66
#define F_HOST	67
#define T_IPREVERSE	68
#define I_IPREVERSE	69
#define E_NOMATCH	70
#define E_LEXDNS	71
#define N_CONFIG	72
#define E_NOIPWCNAME	73
#define H_SECONDARIES	74
#define H_DOMAIN	75
#define T_DEFAULTIP	76
#define T_IPCONFLICT	77
#define I_IPCONFLICT	78
#define I_DOREV	79
#define F_ALLOCTO	80
#define H_HOST	81
#define E_EXMISSING	82
#define E_DOMEXIST	83
#define E_NORANGE	84
#define E_NOIPAVAIL	85
#define E_IVLDOPT	86
#define M_FEATURES	87
#define F_FORWARDONLY	88
#define I_FORWARDONLY	89
#define F_NORECURSE	90
#define I_NORECURSE	91
#define F_NOFETCHGLUE	92
#define I_NOFETCHGLUE	93
#define F_QUERYLOG	94
#define T_DNSFEATURES	95
#define F_XFERNETS	96
#define F_BOGUSNS	97
#define F_FAKEIQUERY	98
#define N_NOFORWARDER	99
#define M_DNSSERVER	100
#define E_ISASECOND	101
#define E_ISAPRIMARY	102
#define M_dnsconf	103
#define E_IVLDKEYW	104
#define N_DNSUPDATED	105
#define F_SEARCHLIST	106
#define T_FEATURES	107
#define T_MVIRTUAL	108
#define E_VHOSTEXIST	109
#define T_BASEINFO	110
#define E_BIND8LEX	111
#define E_EXPECTARG1	112
#define E_EXPECTTYPE	113
#define E_IVLDIP	114
#define E_ZONETYPE	115
#define E_EXPECTED	116
#define E_IVLDHOSTIP	117
#define E_SETHOSTPART	118
#define F_ALLOWTRANS	119
#define F_ALLOWQUERY	120
#define F_LISTENON	121
#define T_ACCESS	122
#define F_ALLOWUPDATE	123
#define F_ALSONOTIFY	124
#define H_ACLS	125
#define I_ADDMATCH	126
#define T_ACL	127
#define I_ADDACL	128
#define T_ACLS	129
#define M_ACL	130
#define M_LOGGING	131
#define H_ACL	132
#define I_DELACL	133
#define M_SECURITY	134
#define F_NETHOSTACL	135
#define F_NETSIZE	136
#define I_DELADDR	137
#define T_ADDRMATCH	138
#define I_ADDRMATCH	139
#define E_HOSTIP	140
#define E_IVLDACL	141
#define E_NETWORKIP	142
#define E_NETSIZE	143
#define M_ACCESS	144
#define T_DNSACCESS	145
#define B_EDITNAME	146
#define T_ACLNAME	147
#define I_ACLNAME	148
#define E_NOSPACE	149
#define F_ACLNAME	150
#define F_NOTIFY	151
#define I_NO	152
#define I_YES	153
#define I_DEFAULT	154
#define F_SECLIST	155
#define B_PREVIEW	156
#define N_NOTTRANSYET	157
#define F_MAINSERV	158
#define F_ADMINMAIL	159
#define F_REFRESH	160
#define F_RETRY	161
#define F_EXPIRE	162
#define F_TTL	163
#define B_UPDATE	164
#define Q_UPDATESLAVE	165
#define I_UPDATESLAVE	166
#define E_STUBNOTIMPLEMENTED	167
#define M_ZONE_FORWARD	168
#define F_FORLIST	169
#define T_FORSPEC	170
#define I_FORSPEC	171
#define Q_DELFORWARD	172
#define E_FILLDOMU	173
#define H_FORWARDS	174
#define I_ADDFOR	175
#define T_FORWARDS	176
#define I_FORWARDS	177
#define I_BASICCONFLICT	178
#define Q_UPDATEANYWAY	179
#define F_SYNCBASIC	180
#define I_SYNCBASIC	181
#define E_INCLUDE	182
#define E_TOOMANYINCL	183
#define F_MINTTL	184
#define E_NODIRCHROOT	185
#define F_CHROOT	186
#define T_EXTRAINFO	187
#define I_ALLISOPT	188
#define F_ADMIN	189
#define F_COMMENT	190
#define F_RENEWDATE	191
#define F_REGISTRAR	192
#define E_SECEXIST	193
#define E_NBPRIM	194
#define F_TEMPLATEDOM	195
#define E_TEMPLATEDOM	196
#define E_DIRPATH	197
#define B_GROWFORM	198
#define I_GROWFORM	199
#define F_SUBNETSPEC	200
#define E_IVLDSUBNET	201
#define F_IP	202
#define F_SERVER	203
#define H_DOMAINREV	204
#define Q_DNSNOTSYNCED	205
#define T_DNSNOTSYNCED	206
#define F_ALLOWRECURSION	207
